/*
   FALCON - The Falcon Programming Language.
   FILE: heap_linux.cpp

   Initialization of heap_linux variables.
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: gio set 30 2004

   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

/** \file
   Short description
*/

#include <falcon/heap.h>

namespace Falcon
{
   long HeapMem::m_pageSize = 0;
}


/* end of heap_linux.cpp */
